@@ -26,10 +26,10 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #include <config.h>
 #endif
 
-#include <climits>
 #include <cstdlib>
 #include <cstdio>
 
+#include <limits>
 #include <string>
 
 #ifdef HAVE_UNISTD_H
@@ -48,15 +48,14 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 // this function.
 
 // Sometimes you need a large integer, but not always.
-// FIXME -- INT_MAX and INT_MIN are probably not right for 64-bits.
 
 octave_idx_type
 NINTbig (double x)
 {
-  if (x > INT_MAX)
-    return INT_MAX;
-  else if (x < INT_MIN)
-    return INT_MIN;
+  if (x > std::numeric_limits<octave_idx_type>::max ())
+    return std::numeric_limits<octave_idx_type>::max ();
+  else if (x < std::numeric_limits<octave_idx_type>::min ())
+    return std::numeric_limits<octave_idx_type>::min ();
   else
     return static_cast<octave_idx_type> ((x > 0) ? (x + 0.5) : (x - 0.5));
 }
@@ -64,10 +63,10 @@ NINTbig (double x)
 int
 NINT (double x)
 {
-  if (x > INT_MAX)
-    return INT_MAX;
-  else if (x < INT_MIN)
-    return INT_MIN;
+  if (x > std::numeric_limits<int>::max ())
+    return std::numeric_limits<int>::max ();
+  else if (x < std::numeric_limits<int>::min ())
+    return std::numeric_limits<int>::min ();
   else
     return static_cast<int> ((x > 0) ? (x + 0.5) : (x - 0.5));
 }
@@ -210,7 +209,7 @@ octave_fgetl (FILE *f, bool& eof)
 }
 
 static inline double
-read_inf_nan_na (std::istream& is, char c)
+read_inf_nan_na (std::istream& is, char c, char sign = '+')
 {
   double d = 0.0;
 
@@ -223,7 +222,7 @@ read_inf_nan_na (std::istream& is, char c)
 	  {
 	    is >> c;
 	    if (c == 'f' || c == 'F')
-	      d = octave_Inf;
+	      d = sign == '-' ? -octave_Inf : octave_Inf;
 	    else
 	      is.putback (c);
 	  }
@@ -263,18 +262,48 @@ octave_read_double (std::istream& is)
 {
   double d = 0.0;
 
-  char c = 0;
+  char c1 = 0;
 
-  is >> c;
-  switch (c)
+  is >> c1;
+  switch (c1)
     {
+    case '-':
+      {
+	char c2 = 0;
+	is >> c2;
+	if (c2 == 'i' || c2 == 'I')
+	  d = read_inf_nan_na (is, c2, c1);
+	else
+	  {
+	    is.putback (c2);
+	    is.putback (c1);
+	    is >> d;
+	  }
+      }
+      break;
+
+    case '+':
+      {
+	char c2 = 0;
+	is >> c2;
+	if (c2 == 'i' || c2 == 'I')
+	  d = read_inf_nan_na (is, c2, c1);
+	else
+	  {
+	    is.putback (c2);
+	    is.putback (c1);
+	    is >> d;
+	  }
+      }
+      break;
+
     case 'i': case 'I':
     case 'n': case 'N':
-      d = read_inf_nan_na (is, c);
+      d = read_inf_nan_na (is, c1);
       break;
 
     default:
-      is.putback (c);
+      is.putback (c1);
       is >> d;
     }
 
