@@ -14,7 +14,8 @@
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.
+## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+## 02110-1301 USA.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} frdemo ()
@@ -545,9 +546,7 @@ function frdemo ()
           eval(cmd);
           disp("\nTo view the system's nyquist plot, execute the following");
           disp("commands:\n");
-          cmd = "__gnuplot_set__ xrange [-4:2];";
-          disp(cmd); eval(cmd);
-          cmd = "__gnuplot_set__ yrange [-2.5:2.5];";
+          cmd = "axis ([-4, 2, -2.5, 2.5]);";
           disp(cmd); eval(cmd);
           cmd = "nyquist(dsys3);";
           run_cmd;
