@@ -14,7 +14,8 @@
 ##
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, 59 Temple Place, Suite 330, Boston, MA 02111 USA.
+## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+## 02110-1301 USA.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} ord2 (@var{nfreq}, @var{damp}, @var{gain})
@@ -66,10 +67,10 @@ function outsys = ord2 (nfreq, damp, gain)
   ## Updates
 
   if(nargin != 2 & nargin != 3)
-    usage("outsys = ord2(nfreq, damp[, gain])")
+    print_usage ();
   endif
   if (nargout > 1)
-    usage("outsys = ord2(nfreq, damp[, gain])")
+    print_usage ();
   endif
   if (nargin == 2)
     gain = 1.0;
