@@ -20,7 +20,7 @@
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {@var{zi}=} bicubic (@var{x}, @var{y}, @var{z}, @var{xi}, @var{yi})
 ##
-## Return a matrix @var{zi} corresponding to the the bicubic
+## Return a matrix @var{zi} corresponding to the bicubic
 ## interpolations at @var{xi} and @var{yi} of the data supplied
 ## as @var{x}, @var{y} and @var{z}. 
 ##
@@ -70,7 +70,7 @@ function F = bicubic (X, Y, Z, XI, YI, spline_alpha)
       if (rz != length (Y) || cz != length (X))
 	error ("length of X and Y must match the size of Z");
       endif
-    elseif (size(X) == size(Y) && size(X) == size(Z))
+    elseif (size_equal (X, Y) && size_equal (X, Z))
       X = X(1,:);
       Y = Y(:,1);
     else
@@ -194,5 +194,4 @@ endfunction
 %! yi=linspace(min(y),max(y),26);
 %! mesh(xi,yi,bicubic(x,y,A,xi,yi));
 %! [x,y] = meshgrid(x,y);
-%! __gnuplot_raw__ ("set nohidden3d;\n")
 %! hold on; plot3(x(:),y(:),A(:),"b*"); hold off;
