@@ -26,7 +26,7 @@
 ##
 ## Two-dimensional interpolation. @var{x}, @var{y} and @var{z} describe a
 ## surface function. If @var{x} and @var{y} are vectors their length
-## must correspondent to the size of @var{z}. @var{x} and @var{Yy must be
+## must correspondent to the size of @var{z}. @var{x} and @var{Yy} must be
 ## monotonic. If they are matrices they  must have the @code{meshgrid} 
 ## format. 
 ##
@@ -53,16 +53,16 @@
 ##
 ## @table @asis
 ## @item 'nearest'
-## Return the nearest neighbour.
+## Return the nearest neighbor.
 ## @item 'linear'
-## Linear interpolation from nearest neighbours
+## Linear interpolation from nearest neighbors.
 ## @item 'pchip'
-## Piece-wise cubic hermite interpolating polynomial
+## Piece-wise cubic hermite interpolating polynomial (not implemented yet).
 ## @item 'cubic'
-## Cubic interpolation from four nearest neighbours
+## Cubic interpolation from four nearest neighbors.
 ## @item 'spline'
 ## Cubic spline interpolation--smooth first and second derivatives
-## throughout the curve (Not implemented yet).
+## throughout the curve (not implemented yet).
 ## @end table
 ##
 ## If a scalar value @var{extrapval} is defined as the final value, then
@@ -164,10 +164,10 @@ function ZI = interp2 (varargin)
   ## If X and Y vectors produce a grid from them
   if (isvector (X) && isvector (Y))
     [X, Y] = meshgrid (X, Y);
-  elseif (! all (size (X) == size (Y)))
+  elseif (! size_equal (X, Y))
     error ("X and Y must be matrices of same size");
   endif
-  if (any (size (X) != size (Z)))
+  if (! size_equal (X, Z))
     error ("X and Y size must match Z dimensions");
   endif
 
@@ -175,7 +175,7 @@ function ZI = interp2 (varargin)
   if ((rows (XI) == 1 && columns (YI) == 1)
       || (columns (XI) == 1 && rows (YI) == 1))
     [XI, YI] = meshgrid (XI, YI);
-  elseif (any (size (XI) != size (YI)))
+  elseif (! size_equal (XI, YI))
     error ("XI and YI must be matrices of same size");
   endif
 
@@ -239,7 +239,6 @@ endfunction
 %! yi=linspace(min(y),max(y),26)';
 %! mesh(xi,yi,interp2(x,y,A,xi,yi,'linear'));
 %! [x,y] = meshgrid(x,y); 
-%! __gnuplot_raw__ ("set nohidden3d;\n")
 %! hold on; plot3(x(:),y(:),A(:),"b*"); hold off;
 
 %!demo
@@ -249,7 +248,6 @@ endfunction
 %! yi=linspace(min(y),max(y),26)';
 %! mesh(xi,yi,interp2(x,y,A,xi,yi,'nearest'));
 %! [x,y] = meshgrid(x,y); 
-%! __gnuplot_raw__ ("set nohidden3d;\n")
 %! hold on; plot3(x(:),y(:),A(:),"b*"); hold off;
 
 %!#demo
@@ -259,7 +257,6 @@ endfunction
 %! yi=linspace(min(y),max(y),26);
 %! mesh(xi,yi,interp2(x,y,A,xi,yi,'cubic'));
 %! [x,y] = meshgrid(x,y); 
-%! __gnuplot_raw__ ("set nohidden3d;\n")
 %! hold on; plot3(x(:),y(:),A(:),"b*"); hold off;
 
 %!test % simple test
