@@ -33,11 +33,11 @@ function map = gray (number)
   if (nargin == 0)
     number = 64;
   elseif (nargin > 1)
-    usage ("gray (number)");
+    print_usage ();
   endif
 
   gr = [0:(number-1)]';
 
-  map = [ gr, gr, gr ] / (number - 1);
+  map = colormap ([ gr, gr, gr ] / (number - 1));
 
 endfunction
