@@ -23,8 +23,8 @@
 ## @deftypefnx {Function File} {} imshow (@var{im}, @var{map})
 ## @deftypefnx {Function File} {} imshow (@var{R}, @var{G}, @var{B}, @dots{})
 ## @deftypefnx {Function File} {} imshow (@var{filename})
-## @deftypefnx {Function File} {} imshow (@dots{}, @var{string_param1}, @var{value1}, ...)
-## Display the image @var{im}, where @var{im} can a 2-dimensional
+## @deftypefnx {Function File} {} imshow (@dots{}, @var{string_param1}, @var{value1}, @dots{})
+## Display the image @var{im}, where @var{im} can be a 2-dimensional
 ## (gray-scale image) or a 3-dimensional (RGB image) matrix. If three matrices
 ## of the same size are given as arguments, they will be concatenated into
 ## a 3-dimensional (RGB image) matrix.
@@ -44,12 +44,8 @@
 ## If given, the parameter @var{string_param1} has value
 ## @var{value1}. @var{string_param1} can be any of the following:
 ## @table @samp
-## @item "display_range"
+## @item "displayrange"
 ## @var{value1} is the display range as described above.
-##
-## @item "InitialMagnification"
-## @var{value1} sets the zoom level in percent. 
-## If @var{value1} is 100 the image is showed unscaled.
 ## @end table
 ## @seealso{image, imagesc, colormap, gray2ind, rgb2ind}
 ## @end deftypefn
@@ -75,8 +71,8 @@ function imshow (im, varargin)
       && ndims (im) == 2
       && ndims (varargin{1}) == 2
       && ndims (varargin{2}) == 2
-      && size (im) == size (varargin{1})
-      && size (im) == size (varargin{2}))
+      && size_equal (im, varargin{1})
+      && size_equal (im, varargin{2}))
     im(:,:,3) = varargin{2};
     im(:,:,2) = varargin{1};
     varargin(1:2) = [];
@@ -97,7 +93,7 @@ function imshow (im, varargin)
   ## Set other default parameters.
   isindexed = false;
   initial_magnification = 100;
-  old_colormap = color_map = colormap ();
+  color_map = colormap ();
   
   ## Handle the rest of the arguments.
   narg = 1;
@@ -110,14 +106,14 @@ function imshow (im, varargin)
     elseif (ismatrix (arg) && size (arg, 2) == 3)
       color_map = arg;
       isindexed = true;
-    elseif (ischar (arg) && strcmpi (arg, "truesize"))
-      initial_magnification = 100;
     elseif (ischar (arg) && strcmpi (arg, "displayrange"))
       narg++;
       display_range = varargin{narg};
-    elseif (ischar (arg) && strcmpi (arg, "initialmagnification"))
+    elseif (ischar (arg) &&
+	    (strcmpi (arg, "truesize") ||
+             strcmpi (arg, "initialmagnification")))
       narg++;
-      initial_magnification = varargin{narg};
+      warning ("image: zoom argument ignored -- use GUI features");
     else
       warning ("imshow: input argument number %d is unsupported", narg) 
     endif
@@ -130,6 +126,13 @@ function imshow (im, varargin)
     im = real (im);
   endif
   
+  nans = isnan (im(:));
+  if (any (nans))
+    warning ("Octave:imshow-NaN",
+	     "imshow: pixel with NaN or NA values are set to zero");
+    im(nans) = display_range(1);
+  endif
+
   ## Scale the image to the interval [0, 1] according to display_range.
   if (! isindexed)
     low = display_range(1);
@@ -138,22 +141,21 @@ function imshow (im, varargin)
     im(im < 0) = 0;
     im(im > 1) = 1;
   endif
-  
-  ## Convert to indexed image.
+
   dim = ndims (im);
   if (dim == 2)
     im = round ((size (color_map, 1) - 1) * im);
+    image (im);
+    colormap (color_map);
   elseif (dim == 3 && size (im, 3) == 3)
-    [im, color_map] = rgb2ind (im);
+    __img__ ([] , [], im);
+    ## FIXME -- needed anymore for a special case?
+    ## Convert to indexed image.
+    ## [im, color_map] = rgb2ind (im);
   else
     error ("imshow: input image must be a 2D or 3D matrix");
   endif
   
-  ## And now, we show the image.
-  colormap (color_map);
-  image (im, initial_magnification/100);
-  colormap (old_colormap);
-
 endfunction
 
 %!error imshow ()                           # no arguments
@@ -164,10 +166,6 @@ endfunction
 %!demo
 %!  imshow (loadimage ("default.img"));
 
-%!demo
-%!  I = loadimage ("default.img");
-%!  imshow (I, "truesize")
-
 %!demo
 %!  [I, M] = loadimage ("default.img");
 %!  imshow (I, M);
