@@ -24,30 +24,18 @@
 
 ## Author: jwe
 
-function h = __axis_label__ (caller, text)
+function retval = __axis_label__ (caller, txt, varargin)
 
-  if (nargin == 0)
-    usage ("__axis_label__ (caller, text)");
-  elseif (nargin == 2)
-    if (ischar (text))
-      __gnuplot_raw__ (sprintf ("set %s \"%s\";\n", caller,
-				undo_string_escapes (text)));
-      if (automatic_replot)
-	replot ();
-      endif
-    else
-      error ("%s: text must be a string", caller);
+  if (ischar (txt))
+    ## FIXME -- should be able to use text instead of __go_text__.
+    ca = gca ();
+    h = __go_text__ (ca, "string", txt, varargin{:});
+    set (ca, caller, h);
+    if (nargout > 0)
+      retval = h;
     endif
   else
-    usage ("%s (text)", caller);
-  endif
-
-  ## FIXME -- eventually, we will return a graphics handle.  For
-  ## now, return something, so that calls that expect a handle won't
-  ## fail (at least immediately).
-
-  if (nargout > 0)
-    h = -1;
+    error ("%s: expecting first argument to be character string");
   endif
 
 endfunction
